<?php
/**
 * Clase para traducir con Google Translate
 *
 * @version 0.0.1
 * @author Jose Carlos Cruz Parra http://programadorphpfreelance.com
 *
 */
class GoogleTranslate
{
	private $_key;
	private $_t;
	private $_f;
	private $_base = 'https://www.googleapis.com/language/translate/v2';
	/**
	 * Constructor
	 *
	 * @param string $key
	 * @param string $f
	 * @param string $t
	 */
	function __construct($key, $f='es', $t='en')
	{
		$this->_key = $key;
		$this->_f = $f;
		$this->_t = $t;
	}

	private function getUrl($q, $params=array())
	{
		if(empty($this->_key))
		{
			return false;
		}

		$url = $this->_base;

		switch($q)
		{
			case 't':
				$url .= '?';
				break;
			case 'd':
				$url .= '/detect?';
				break;
			case 'l':
				$url .= '/languages?';
				break;
		}

		$url .= 'key='.$this->_key;

		foreach($params as $key=>$value)
		{
			$url .= sprintf('&%s=%s', urlencode($key), urlencode($value));
		}

		return $url;
	}

	private function getData($url)
	{
		if(!$url)
		{
			return false;
		}

		$curl = new MyCurl();

		$response = $curl->Go($url);

		/*
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
		$response = curl_exec($ch);
		curl_close($ch);
		*/

		//TODO: Check errores

		if($response)
		{
			$obj = json_decode($response);

			if(is_object($obj) && isset($obj->data))
			{
				return $obj;
			}
		}

		return false;
	}
	/**
	 * Traduce una cadena.
	 *
	 * @param string $str
	 * @param string $f
	 * @param string $t
	 * @return string
	 */
	public function Translate($str, $f=null, $t=null)
	{
		if(is_null($f))
		{
			$f = $this->_f;
		}

		if(is_null($t))
		{
			$t = $this->_t;
		}

		if($f == $t)
		{
			return $str;
		}

		$obj = $this->getData($this->getUrl('t', array('source'=>$f, 'target'=>$t, 'q'=>$str)));

		return $obj ? $obj->data->translations[0]->translatedText : $str;
	}
	/**
	 * Traduce una cadena (es un alias del método Translate).
	 *
	 * @param string $str
	 * @param string $f
	 * @param string $t
	 * @return string
	 */
	public function T($str, $f=null, $t=null)
	{
		return $this->Translate($str, $f, $t);
	}
	/**
	 * Trata de detectar el idioma de una cadena.
	 *
	 * @param string $str
	 * @return string
	 */
	public function Detect($str)
	{
		$obj = $this->getData($this->getUrl('d', array('q'=>$str)));

		return $obj ? $obj->data->detections[0][0]->language : '??';
	}
	/**
	 *
	 * @return array
	 */
	public function GetLanguages()
	{
		$obj = $this->getData($this->getUrl('l'));
		$arr = $obj ? $obj->data->languages : array();

		$langs = array();
		foreach($arr as $item)
		{
			$langs[$item->language] = $item->language;
		}

		return $langs;
	}
}
?>