<?php
/**
 * Class to draw a full year calendar
 * @author José Carlos Cruz Parra AKA internia
 * josecarlos@programadorphpfreelance.com
 * http://programadorphpfreelance.com
 * 2010-2013
 * This code is released under the GNU General Public License.
 */
class MyCalendar
{
	private $_ano;
	private $_mes;
	private $_marcas;
	private $_titulo;

	function __construct($ano=null, $titulo="Calendario [*ano*]", $mes=null)
	{
		$this->SetAno(is_null($ano) ? date("Y") : $ano);
		$this->SetMes(is_null($mes) ? date("n") : $mes);
		$this->_marcas = array();
		$this->_titulo = $titulo;
	}

	public function SetAno($ano)
	{
		$this->_ano = intval($ano);
	}

	public function SetMes($mes)
	{
		$this->_mes = intval($mes);
	}

	public function SetTitulo($titulo)
	{
		$this->_titulo = $titulo;
	}

	public function AddMarca($dia, $mes, $ano, $diasemana, $clase, $title="", $onclick="")
	{
		if(isset($this->_marcas[$dia.$mes.$ano.$diasemana]))
		{
			if($clase) $this->_marcas[$dia.$mes.$ano.$diasemana]['clase'] .= ' '.$clase;
			if($title) $this->_marcas[$dia.$mes.$ano.$diasemana]['title'] .= '. '.$title;
			if($onclick && $onclick != $this->_marcas[$dia.$mes.$ano.$diasemana]['onclick']) $this->_marcas[$dia.$mes.$ano.$diasemana]['onclick'] .= '; '.$title;
		}
		else
		{
			$this->_marcas[$dia.$mes.$ano.$diasemana] = array(
				"dia"=>$dia,
				"mes"=>$mes,
				"ano"=>$ano,
				"diasemana"=>$diasemana,
				"clase"=>$clase,
				"title"=>$title,
				"onclick"=>$onclick,
				);
		}
	}

	public function GetAnoHTML($ano=null)
	{
		$ano = is_null($ano) ? $this->_ano : intval($ano);

		$html = "";

		if($this->_titulo)
		{
			$html .= sprintf("<h3>%s</h3>\n", str_replace("[*ano*]", $ano, $this->_titulo));
		}

		$html .= "<table class=\"calendario ano\"><tr>\n";

		//MESES
		for($mes=1; $mes<13; $mes++)
		{
			$html .= "<td class=\"mes\">\n\t".ucfirst(strftime("%B", mktime(0, 0, 0, $mes, 1, $ano)))."\n\t".$this->GetJustMes($mes, $ano, false)."\n</td>\n";

			if($mes == 3 || $mes == 6 || $mes == 9)
			//if($mes == 4 || $mes == 8)
			{
				$html .= "</tr><tr>\n";
			}
		}

		$html .= "</tr></table>\n";

		return $html;
	}

	public function GetMesHTML($ano=null, $mes=null)
	{
		$ano = is_null($ano) ? $this->_ano : intval($ano);
		$mes = is_null($mes) ? $this->_mes : intval($mes);

		$html = "";

		if($this->_titulo)
		{
			$html .= sprintf("<h3>%s</h3>\n", str_replace(array("[*ano*]", "[*mes*]"), array($ano, $mes), $this->_titulo));
		}

		$html .= "<table class=\"calendario mes\"><tr>\n";
		$html .= "<td class=\"mes\">\n\t".ucfirst(strftime("%B", mktime(0, 0, 0, $mes, 1, $ano)))."\n\t".$this->GetJustMes($mes, $ano, true)."\n</td>\n";
		$html .= "</tr></table>\n";

		return $html;
	}

	private function GetJustMes($mes, $ano, $mostrarInfoDias)
	{
		$dia = 1;
		$time = mktime(0, 0, 0, $mes, $dia, $ano);
		$diasemana = date("w", $time);
		$diasemana = $diasemana == 0 ? 6 : $diasemana-1;
		$diasmes = date("t", $time);

		$html = "<table>\n\t<tr><th>Lun</th><th>Mar</th><th>Mie</th><th>Jue</th><th>Vie</th><th>Sab</th><th>Dom</th></tr>\n";

		$retener = true;

		//SEMANAS
		for($c=0; $c<6; $c++)
		{
			$html .= "\n\t<tr>";

			//DIAS
			for($k=0; $k<7; $k++)
			{
				if($retener)
				{
					if($diasemana == $k)
					{
						$retener = false;
					}
				}

				/*if($dia > $diasmes)
				{
					$dia = 1;
					$mes++;
					$diasmes = date("t", mktime(0, 0, 0, $mes, $dia, $ano));
				}*/

				if($retener || $dia > $diasmes)
				{
					$html .= "<td class=\"dia vacio\"></td>";
				}
				else
				{
					$class = "dia";
					$title = "";
					if($ano.$mes.$dia == date("Ynj"))
					{
						$class .= " hoy";
						$title .= "Hoy";
					}
					$marca = $this->GetMarcaDia($dia, $mes, $ano);
					if(!empty($marca))
					{
						$class .= " ".$marca["clase"];
						$title .= " ".$marca["title"];
					}

					$html .= "<td class=\"{$class}\" title=\"{$title}\" ".(empty($marca['onclick']) ? '' : 'onclick="'.$marca['onclick'].'"').">{$dia}";
					if($mostrarInfoDias)
					{
						$html .= "<div>".truncar($title, 18)."</div>";
					}
					$html .= "</td>";

					$dia++;

					if($dia <= $diasmes)
					{
						$time = mktime(0, 0, 0, $mes, $dia, $ano);
						$diasemana = date("w", $time);
						$diasemana = $diasemana == 0 ? 6 : $diasemana-1;
						$diasmes = date("t", $time);
					}
				}
			}

			$html .= "</tr>";
		}

		$html .= "\t</table>";

		return $html;
	}

	public function GetMarcaDia($dia, $mes, $ano)
	{
		$time = mktime(0, 0, 0, $mes, $dia, $ano);
		$diasemana = date("w", $time);

		$keys = array(
			$dia.$mes.$ano.$diasemana,
			$dia.$mes.$ano."*",
			$dia.$mes."**",
			$dia."***",
			"***".$diasemana,
			);
		foreach($keys as $key)
		{
			if(isset($this->_marcas[$key]))
			{
				return $this->_marcas[$key];
			}
		}

		return array();
	}
}
?>