<?php
/**
 * Jose Carlos Cruz Parra
 * programadorphpfreelance.com
 * 2010-05-02
 * 2011-12-12
 * 2012-02-03
 *
 * SIMPLE WEB PHP EDICION ADMINISTRADA
 *
 * inc/classes/SWPHP_Pagina.class.php
 *
 * Clase página, para mostrar contenido en SWPHP
 *
 */
class SWPHP_Pagina
{
	private $_id = 0;
	private $_keys = array(
		'titulo',
		'title',
		'descripcion',
		'keywords',
		'contenido',
		'icono',
		'considebox',
		'estilo_id',
		'modulo_clave',
		'simodulo',
		'robots',
		);
	private $_data = array();
	private $_notfound = false;
	private $_canonical = null;
	private $_procesarContenido = false;
	/**
	 * Constructor
	 *
	 * @return SWPHP_Pagina
	 */
	function __construct()
	{
		$this->Reset();
	}
	/**
	 * Resetea la página a sus valores por defecto
	 *
	 */
	function Reset()
	{
		$this->_id = 0;

		$this->_data = array();

		foreach($this->_keys as $key)
		{
			$this->_data[$key] = '';
		}

		$this->_notfound = false;
		$this->_canonical = null;
	}
	/**
	 * Asigna todos los valores a la página.
	 *
	 * @param string $titulo
	 * @param string $title
	 * @param string $descripcion
	 * @param string $keywords
	 * @param string $contenido
	 * @param string $icono
	 * @param bool $considebox
	 * @param int $estilo_id
	 * @param string $modulo_clave
	 * @param string $robots
	 */
	function SetValues($titulo='', $title='', $descripcion='', $keywords='', $contenido='', $icono='', $considebox=false, $estilo_id=0, $modulo_clave='', $robots='all', $simodulo=1)
	{
		foreach($this->_keys as $key)
		{
			$this->_data[$key] = isset($$key) ? $$key : '';
		}
	}
	/**
	 * Asigna un valor.
	 * Devuelve true si la asignación es correcta ($key existe como tal), false si no.
	 *
	 * @param string $key
	 * @param mixed $value
	 * @return bool
	 */
	function SetValue($key, $value)
	{
		if(in_array($key, $this->_keys))
		{
			$this->_data[$key] = $value;
			return true;
		}
		return false;
	}
	/**
	 * Obtiene un valor, el correspondiente a $key
	 * Si $key no existe como tal, devuelve false.
	 *
	 * @param string $key
	 * @return mixed
	 */
	function GetValue($key)
	{
		if(in_array($key, $this->_keys))
		{
			switch($key)
			{
				case 'robots':
					global $swphp_config;

					if(isset($swphp_config['noindexar']) && $swphp_config['noindexar'])
					{
						return 'none';
					}

					break;
			}

			return $this->_data[$key];
		}
		return false;
	}
    /**
     * Añade una cadena a un valor, el correspondiente a $key
     * Si $key no existe como tal, devuelve false
     *
     * @param string $key
     * @param string $value
     * @param string $sep
     * @return boolean
     */
    function Append($key, $value, $sep=' ')
    {
        if(in_array($key, $this->_keys))
		{
			$this->_data[$key] .= $sep.$value;
			return true;
		}
		return false;
    }
	/**
	 * Carga los valores desde un registro de la tabla de páginas según su id.
	 * Devuelve true si se carga correctamente, false si no.
	 *
	 * @param int $id
	 * @return bool
	 */
	function LoadFromId($id)
	{
		return $this->LoadFromFilter(sprintf("id = '%u'", $id));
	}
	/**
	 * Carga los valores desde un registro de la tabla de páginas según su friendly, padre_id y activo.
	 * Devuelve true si se carga correctamente, false si no.
	 *
	 * @param string $friendly
	 * @param int $padre_id
	 * @param bool $activo
	 * @return bool
	 */
	function LoadFromFriendly($friendly, $padre_id, $activo=true)
	{
		return $this->LoadFromFilter(sprintf("friendly = '%s' AND padre_id = '%u'", addcslashes($friendly,"'"), $padre_id, $activo ? 1 : 0));
	}
	/**
	 * Carga los valores desde un registro de la tabla de páginas según un filtro sql.
	 * Devuelve true si se carga correctamente, false si no.
	 *
	 * @param string $filtro
	 * @return bool
	 */
	function LoadFromFilter($filtro)
	{
		global $db;

		$aux = array_slice($this->_keys, 0, 10);

		//TODO: poner robots como campo de paginas y quitar aux de aquí porque no hará falta ya

		$row = $db->GetRow(sprintf("SELECT id, %s, activo FROM ".SWPHP_DBPREFIX."paginas AS p JOIN ".SWPHP_DBPREFIX."paginas_idiomas AS pi ON p.id = pi.pagina_id AND pi.idioma_id = '{$_SESSION['SWPHP_IDIOMA_ACTUAL']}' WHERE %s", implode(',', $aux), $filtro), true, false);
		if($row)
		{
			$this->_id = $row['id'];

			if(!$row['activo'])
			{
				$row['contenido'] = 'Contenido no disponible';
				$row['icono'] = 'warning';
				$row['robots'] = 'noindex, follow';
			}

			unset($row['id'], $row['activo']);
			$this->_data = $row;

			return true;
		}

		return false;
	}
	/**
	 * Carga los valores desde un registro de la tabla de módulos (para una página de administración)
	 * Devuelve true si se carga correctamente, false si no.
	 *
	 * @param string $clave
	 * @param bool $activo
	 * @return bool
	 */
	/*function LoadFromModule($clave, $activo=true)
	{
		global $db;

		$row = $db->GetRow(sprintf("SELECT id, titulo, descripcion, icono FROM ".SWPHP_DBPREFIX."modulos WHERE clave = '%s' AND activo = '%s'", addcslashes($clave, "'"), $activo ? 1 : 0), true, false);
		if($row)
		{
			$this->Reset();

			$this->_id = $row['id'];
			unset($row['id']);
			foreach($row as $key=>$value)
			{
				$this->SetValue($key, $value);
			}

			return true;
		}

		return false;
	}*/
	/**
	 * Establece los valores para página no encontrada
	 * e indica al header: HTTP/1.0 404 Not Found
	 *
	 */
	function NotFound($addToBreadcrumbs=true)
	{
		header("HTTP/1.0 404 Not Found");

		$this->SetValues(
			l('Página no encontrada'),
			'',
			l('La página solicitada no se encuentra en el servidor.'),
			l('pagina, no, encontrada'),
			l('La página solicitada no se encuentra en el servidor.'),
			'exclamation.png',
			false,
			0,
			'',
			'none'
			);

		if($addToBreadcrumbs)
		{
			$this->AddToBreadcrumbs();
		}

		$this->_notfound = true;
	}
	/**
	 * Obtiene si es página no encontrada o no lo es
	 *
	 * @return bool
	 */
	function GetNotFound()
	{
		return $this->_notfound;
	}
	/**
	 * Obtiene el identificador de la página en la tabla de páginas o null si no lo tiene recogido
	 *
	 * @return int
	 */
	function GetId()
	{
		return $this->_id;
	}
	/**
	 * Establece la parte de la url canónica a partir del raiz
	 *
	 * @param string $str
	 */
	function SetCanonical($str)
	{
		$str = trim($str);

		if(strlen($str) > 0)
		{
			if(substr($str, 0, 1) != '/')
			{
				$str = '/'.$str;
			}
		}

		$this->_canonical = $str;
	}
	/**
	 * Obtiene la parte de la url canónica
	 *
	 */
	function GetCanonical()
	{
		return $this->_canonical;
	}
	/**
	 * Obtiene la url canónica completa
	 *
	 * @param string $base
	 * @return string
	 */
	function BuildCanonical($base)
	{
		return ponerBarra($base.(is_null($this->_canonical) ? $_SERVER['REQUEST_URI'] : $this->_canonical));
	}
	/**
	 * Obtiene el contenido,
	 * si la página está asociada a un módulo, devolverá la cadena correspondiente para luego mostrar ese módulo,
	 * si no, devolverá el valor de contenido.
	 *
	 * @param bool $nomodulo
	 * @return string
	 */
	function GetContenido($nomodulo=false)
	{
		return !$nomodulo && $this->_data['modulo_clave'] ? '[swphp:modulo]'.$this->_data['modulo_clave'].'[/swphp]' : $this->_data['contenido'];
	}
	/**
	 * Indica si hay que procesar el contenido o no
	 *
	 * @param bool $val
	 */
	function SetProcesarContenido($val)
	{
		$this->_procesarContenido = $val ? true : false;
	}
	/**
	 * Procesa el contenido si así está indicado
	 *
	 */
	function ProcesarContenido()
	{
		if($this->_procesarContenido)
		{
			$this->_data['contenido'] = SWPHP::_ProcesarContenido($this->_data['contenido']);
		}
	}
	/**
	 * Añade esta página a las miguitas de pan
	 */
	function AddToBreadcrumbs()
	{
		SWPHP::$breadcrumb->Add($this->_canonical ? $this->_canonical : '', $this->_data['titulo'], $this->_data['title'], isset($this->_data['robots']) && $this->_data['robots'] == 'none');
	}
}
