<?php
/**
 * Armando Servillera Torres
 * www.pagina-web-barata.com
 * 2012-01-11
 *
 * SIMPLE WEB PHP EDICION ADMINISTRADA
 *
 * inc/modulos/kapitaltruth/admin/preguntas/admin/functions.inc.php
 *
 */

/**
 * Obtiene un array con todos los sets de respuestas
 *
 * @param int $idioma_id
 * @param bool $htmlentities
 * @return array
 */
function kapitaltruth_preguntas_getSetsRespuestas($idioma_id=SWPHP_IDIOMA_POR_DEFECTO, $htmlentities=true)
{
	global $db;

	$rows = $db->GetRows("SELECT s.id, '' AS nombre FROM ".SWPHP_DBPREFIX."kptl_setsrespuestas AS s", true, false);
	foreach($rows as $key=>$row)
	{
		$rows[$key]['nombre'] = kapitaltruth_preguntas_getNombreSetRespuestas($row['id'], $idioma_id, $htmlentities);
	}

	return $rows;
}
/**
 * Obtiene el nombre de un set de respuestas formándolo con los de las respuestas que lo conforman
 *
 * @param int $setrespuestas_id
 * @param int $idioma_id
 * @param bool $htmlentities
 * @return string
 */
function kapitaltruth_preguntas_getNombreSetRespuestas($setrespuestas_id, $idioma_id=SWPHP_IDIOMA_POR_DEFECTO, $htmlentities=true)
{
	global $db;

	$values = $db->GetValuesQuery("SELECT CONCAT(ri.texto, ' (', r.puntos, ')') FROM ".SWPHP_DBPREFIX."kptl_respuestas_idiomas AS ri JOIN ".SWPHP_DBPREFIX."kptl_respuestas AS r ON r.id = ri.respuesta_id WHERE r.setrespuestas_id = '{$setrespuestas_id}' AND ri.idioma_id = '{$idioma_id}' ORDER BY r.puntos ASC", $htmlentities);

	return implode(' | ', $values);
}
/**
 * Valida los datos de un registro de una pregunta
 *
 * @param array $data
 * @return bool
 */
function kapitaltruth_preguntas_validarDatos($data)
{
	$ok = true;

	$requeridos = array(
		'texto'=>l('Pregunta', 'kapitaltruth'),
		);

	foreach($requeridos as $key=>$nombre)
	{
		if(!isset($data['idiomas'][SWPHP_IDIOMA_POR_DEFECTO][$key]) || $data['idiomas'][SWPHP_IDIOMA_POR_DEFECTO][$key] == '')
		{
			SWPHP::_Msg(l("Falta el dato:", 'kapitaltruth')." {$nombre} ({$swphp_idiomas[SWPHP_IDIOMA_POR_DEFECTO]['nombre']})", "error");
			$ok = false;
		}
	}

	return $ok;
}
/**
 * Prepara los datos para insertar o actualizar una pregunta en la base de datos
 *
 * @param array $data
 * @param int $id
 * @return array
 */
function kapitaltruth_preguntas_prepararDatos($data, $id=0)
{
	global $db;

	foreach($data as $key=>$value)
	{
		switch($key)
		{
			case 'categoria_id':
			case 'setrespuestas_id':
				$data[$key] = intval($value);
				break;
			default:
				//Cualquier otro dato lo descarto
				unset($data[$key]);
				break;
		}
	}

	$ahora = date('Y-m-d H:i:s');
	if($id == 0)
	{
		$data['fechayhoraregistro'] = $ahora;
		$data['user_idregistro'] = $_SESSION['user']['id'];
	}
	$data['fechayhoraultima'] = $ahora;
	$data['user_idultima'] = $_SESSION['user']['id'];

	return $data;
}

/**
 * Elimina una pregunta
 *
 * @param int $id
 */
function kapitaltruth_preguntas_eliminarPregunta($id)
{
	global $db;

	if($db->Execute("DELETE FROM ".SWPHP_DBPREFIX."kptl_preguntas WHERE id = '{$id}'"))
	{
		$db->Execute("DELETE FROM ".SWPHP_DBPREFIX."kptl_preguntas_idiomas WHERE noticia_id = '{$id}'");

		return true;
	}

	return false;
}
/**
 * Prepara los datos para insertar o actualizar datos de una pregunta en idioma
 *
 * @param array $idiomas
 * @param int $idioma_id
 * @param int $id
 * @return array
 */
function kapitaltruth_preguntas_prepararDatosIdioma($idiomas, $idioma_id, $id=0)
{
	$data = SWPHP::_PrepararDatosIdioma($idiomas, $idioma_id, array('texto'));

	if($id)
	{
		$data['pregunta_id'] = $id;
	}
	$data['idioma_id'] = $idioma_id;

	return $data;
}

?>